@@ -1,7 +1,7 @@
 import json
 
 from wp21_train.savers.adapter import adapter
-from wp21_train.utils.logging import log_message
+from wp21_train.utils.logger   import log_message
 
 
 class json_adapter(adapter):
