@@ -1,7 +1,7 @@
 import pickle
 
 from wp21_train.savers.adapter import *
-from wp21_train.utils.logging import log_message
+from wp21_train.utils.logger   import log_message
 
 class pickle_adapter(adapter):
 
