@@ -1,6 +1,6 @@
 import yaml
 from wp21_train.savers.adapter import adapter
-from wp21_train.utils.logging import log_message
+from wp21_train.utils.logger   import log_message
 
 class yml_adapter(adapter):
     def __init__(self, file_name):
